@@ -1,4 +1,4 @@
-from finq import FINQ
+from finq.main import FINQ
 
 
 def test_reduce():
